``influx_s`` and ``influx_i`` are programs designed for flux and metabolite concentration estimation based on labeling data using stable isotopes (essentially ¹³C but combination of multiple isotopes like ²H, ¹³C, ¹⁵N, ... is also possible). ``influx_s`` works with stationary data while the ``influx_i`` is able to simulate instationary labeling (hence the ``_i`` in the name). The both work in metabolically stationary context. The whole project is referred as ``influx_si``. Note also that the term ``influx_si`` is used in contexts where ``influx_s`` and ``influx_i`` are interchangeable.

For installation instructions and more details, you can check the `doc online <https://influx-si.readthedocs.io/>`_.
